@@ -14,7 +14,7 @@ import (
 	"github.com/operator-framework/operator-registry/pkg/registry"
 	opregistry "github.com/operator-framework/operator-registry/pkg/registry"
 
-	"github.com/operator-framework/operator-lifecycle-manager/pkg/api/apis/operators/v1alpha1"
+	"github.com/operator-framework/api/pkg/operators/v1alpha1"
 )
 
 type CatalogKey struct {
@@ -224,6 +224,7 @@ type OperatorSurface interface {
 	Version() *semver.Version
 	SourceInfo() *OperatorSourceInfo
 	Bundle() *api.Bundle
+	Inline() bool
 }
 
 type Operator struct {
@@ -238,24 +239,11 @@ type Operator struct {
 
 var _ OperatorSurface = &Operator{}
 
-func NewOperatorFromBundle(bundle *api.Bundle, replaces string, startingCSV string, sourceKey CatalogKey) (*Operator, error) {
-	if bundle.CsvJson == "" {
-		return nil, fmt.Errorf("no csv json found")
-	}
-	csv := &registry.ClusterServiceVersion{}
-	if err := json.Unmarshal([]byte(bundle.CsvJson), csv); err != nil {
-		return nil, err
-	}
-	r := replaces
-	if r == "" {
-		r, _ = csv.GetReplaces()
-	}
-
-	version, _ := csv.GetVersion()
-	parsedVersion, err := semver.ParseTolerant(version)
-	v := &parsedVersion
+func NewOperatorFromBundle(bundle *api.Bundle, startingCSV string, sourceKey CatalogKey) (*Operator, error) {
+	parsedVersion, err := semver.ParseTolerant(bundle.Version)
+	version := &parsedVersion
 	if err != nil {
-		v = nil
+		version = nil
 	}
 	provided := APISet{}
 	for _, gvk := range bundle.ProvidedApis {
@@ -276,7 +264,11 @@ func NewOperatorFromBundle(bundle *api.Bundle, replaces string, startingCSV stri
 	if len(required) == 0 && len(provided) == 0 {
 		// fallback to csv parsing
 		if bundle.CsvJson == "" {
-			return nil, fmt.Errorf("couldn't parse bundle")
+			if bundle.GetBundlePath() != "" {
+				return nil, fmt.Errorf("couldn't parse bundle path, missing provided and required apis")
+			}
+
+			return nil, fmt.Errorf("couldn't parse bundle, missing provided and required apis")
 		}
 
 		csv := &v1alpha1.ClusterServiceVersion{}
@@ -290,14 +282,12 @@ func NewOperatorFromBundle(bundle *api.Bundle, replaces string, startingCSV stri
 		}
 		op.sourceInfo = sourceInfo
 		op.bundle = bundle
-		op.replaces = r
 		return op, nil
 	}
 
 	return &Operator{
-		name:         csv.GetName(),
-		replaces:     r,
-		version:      v,
+		name:         bundle.CsvName,
+		version:      version,
 		providedAPIs: provided,
 		requiredAPIs: required,
 		bundle:       bundle,
@@ -333,7 +323,6 @@ func NewOperatorFromV1Alpha1CSV(csv *v1alpha1.ClusterServiceVersion) (*Operator,
 	return &Operator{
 		name:         csv.GetName(),
 		version:      &csv.Spec.Version.Version,
-		replaces:     csv.Spec.Replaces,
 		providedAPIs: providedAPIs,
 		requiredAPIs: requiredAPIs,
 		sourceInfo:   &ExistingOperator,
@@ -375,3 +364,7 @@ func (o *Operator) Bundle() *api.Bundle {
 func (o *Operator) Version() *semver.Version {
 	return o.version
 }
+
+func (o *Operator) Inline() bool {
+	return o.bundle != nil && o.bundle.GetBundlePath() == ""
+}
